==> InpboxDB-0.1.71b.tar.gz: InpboxDB/InpboxDBTemplates.py <==
#####################
# Templates Service
#
#####################

Templates={}
Sqls={}
Scripts={}

Templates['selectdbForm_html'] =r"""
<dtml-var standard_html_header>
<dtml-var selectdbForm>
<dtml-var standard_html_footer>
"""
Templates['CSS_Def'] =r"""
<style type="text/css">
  <!--
body{
  background-color:white;
  color:black;
}
.usertext {
  text-align:justified;
  font-size: 10pt;

}
.timetext {
  font-size:smaller;
  text-align:right;
}
.menubox{
  border-style:solid;
  border-color:Black;
  padding:0;border-width:1;
}
.menuline{
  color:White;
  background-color:#778899;
  margin:0;
  border-style:solid;
  border-color:#778899;
  border-width:1;
  padding:3;
}
.labeltitle{
  color: Indigo;
  background-color:Azure;
  font-weight: bold;
}
.nonewrap{
  white-space: nowrap;
}
.mestext {
  background-color: White;
  foreground-color: Black;
  border-style: solid;
  border-width: 1;
  border-color: maroon;
  cursor: pointer;
  padding: 2 10 0 10;
}
.javaitem{
  color: black;
  background-color: white;
  border-style:solid;
  border-color:maroon;
  padding:0;
  border-width:1;
}
input.AsciiEditBox {
  ime-mode: disabled;
  border-style: solid;
  border-width: 1;
  border-color: blue;
}
input.KanjiEditBox {
  ime-mode: active;
  border-style: solid;
  border-width: 1;
  border-color: blue;
}
textarea.KanjiEditBox {
  ime-mode: active;
  width: 100%;
  border-style: solid;
  border-width: 1;
  border-color: blue;
  font-size: 12pt;
}
input.PushButton {
  background-color: White;
  foreground-color: Black;
  border-style: solid;
  border-width: 1;
  border-color: saddlebrown;
  cursor: pointer;
  padding: 2 10 0 10;
}
img.left {
  float: left;
  margin-right: 0.8em;
  margin-bottom: 0.5em;
}
img.right {
  float: right;
  margin-right: 0.8em;
  margin-bottom: 0.5em;
}

p {
  clear: both;
  line-height: 1.4;
}

a.tlink{
  text-decoration: none;
  margin-top: 0.5em;
  margin-right: 0.5em;
  margin-left: 0.5em;
  margin-bottom: 0.5em;
  border-style: solid;
  border-width: 1;
  border-color: white;
  background-color:black;
  Color: white;
  font-size: 9pt;
  padding: 0 4 0 4;

}

.tlink a:link {color: #FFFFFF; text-decoration: none;}
.tlink a:visited {color: #FFFF00; text-decoration: none;}
.tlink a:active {color: #FFFFFF; text-decoration: none;}
.tlink a:hover {color:  RED; text-decoration: none;}
.nomal a:link {color: #204050; text-decoration: none;}
.nomal a:visited {color: #204050; text-decoration: none;}
.nomal a:active {color: #466dab; text-decoration: none;}
.nomal a:hover {color:  #991100; text-decoration: none;}
 -->
</style>
"""
Templates['standard_html_footer'] =r"""
</body>
</html>
"""

Templates['standard_html_header'] =r"""
<html>
  <head>
  <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=<dtml-var dbcharset>">
  <dtml-var CSS_Def>
  <title>
   <dtml-var title_or_id>
  </title>
  </head>
<body bgcolor="#FFFFFF" leftmargin="3" topmargin="3" marginwidth="2" marginheight="2">
"""

Templates['index_html'] =r"""
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
<HEAD>
    <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=<dtml-var dbcharset>">
</HEAD>
<dtml-let us="AUTHENTICATED_USER.getUserName()">
<dtml-if "us=='Anonymous User'">
ǰǤȥ桼ǤϡǤޤ
<dtml-else>

  <FRAMESET COLS="20%,*" BORDER=0 FRAMEBORDER=1 FRAMESPACING=1>
    <FRAME SRC="left_html" NAME="menuFrame" SCROLLING=AUTO />
    <FRAME SRC="work_html" NAME="workFrame" SCROLLING=AUTO />
  </FRAMESET>
<NOFRAMES>
̤Ѥˤϥե졼ɽǤ֥饦ɬפǤ.
</NOFRAMES>
</dtml-if>
</dtml-let>
</HTML>
"""
Templates['left_html'] =r"""
<dtml-var standard_html_header>
<form>
<div class="menubox">
<p class="menuline">
˥塼
</p>
<dtml-comment>
<div style="padding-top: 3pt; padding-bottom: 3pt;">&nbsp;<a href="<dtml-var absolute_url>/index_html"><font size="2">˥塼ȥå<font></a></div>
</dtml-comment>
<div style="padding-top: 3pt; padding-bottom: 3pt;">
&nbsp;<a href="&dtml-absolute_url;/selectdbForm_html" TARGET="workFrame">
<font size="2">ǡ١ѹ<font>
</a>
</div>

<div style="padding-top: 3pt; padding-bottom: 3pt;">
&nbsp;<a href="&dtml-absolute_url;/showTable_html" TARGET="workFrame">
<font size="2">ơ֥ɽ<font>
</a>
</div>

</div>
</form>
<dtml-var standard_html_footer>
"""
Templates['work_html'] =r"""
<dtml-var standard_html_header>
<p>ˡ</p>
<p>
ΥץȤϴԤѤǤ<br>
ľ URL áȻפʤ̤ˤʤǤ礦<br>
ƥꤷƤѲ
</p>
<dtml-var standard_html_footer>
"""

Templates['showTable_html'] =r"""
<dtml-var standard_html_header>
<dtml-var showtblistForm>
<dtml-var standard_html_footer>
"""
Scripts['changeMethod']=["""idst, arg, body""","""from Products.PythonScripts.standard import html_quote

request = container.REQUEST
RESPONSE =  request.RESPONSE

context[idst].manage_edit(title='',connection_id='conid',arguments=arg,template=body)

return
"""]

Scripts['updateScript']=["""tbl, startpos""","""from Products.PythonScripts.standard import html_quote

request = container.REQUEST
RESPONSE =  request.RESPONSE

returl='showedittable?tbl=%s&startpos=%s' % (tbl, startpos)
flds = context.getupdateSQL(tbl)
fld = string.split(flds[0],'\\n')
fldlen = len(fld)
sql=""

for i in range(0,fldlen-1):
  typ=context.getdbtype(tbl,fld[i])
  if typ=="s" or typ=="t":
     sql = sql + '%s="%s",' % (fld[i], request.form['inptext'][i])
  else:
     sql = sql + '%s=%s,' % (fld[i], request.form['inptext'][i])
if len(sql):
  sql = sql[:-1]
  body = "upsql=context.editUpdateSQL\\n"
  body = body + "upsql(%s)" % sql
  context.upgo.ZPythonScript_edit(params='',body=body)
  context.upgo()


RESPONSE.redirect(returl)
 """]

Scripts['deleteScript']=["""tbl, startpos""","""from Products.PythonScripts.standard import html_quote

request = container.REQUEST
RESPONSE =  request.RESPONSE

returl='showedittable?tbl=%s&startpos=%s' % (tbl, startpos)
flds = context.getdeleteSQL(tbl)
fld = string.split(flds[0],'\\n')
fldlen = len(fld)
sql=""

for i in range(0,fldlen-1):
  typ=context.getdbtype(tbl,fld[i])
  if typ=="s" or typ=="t":
     sql = sql + '%s="%s",' % (fld[i], request.form['inptext'][i])
  else:
     sql = sql + '%s=%s,' % (fld[i], request.form['inptext'][i])
if len(sql):
  sql = sql[:-1]
  body = "delsql=context.editDeleteSQL\\n"
  body = body + "delsql(%s)" % sql
  context.delgo.ZPythonScript_edit(params='',body=body)
  context.delgo()


RESPONSE.redirect(returl)
 """]

Scripts['upgo']=["""""",""""""]

Scripts['delgo']=["""""",""""""]

Sqls['editUpdateSQL']=["""""","""select * from a"""]

Sqls['editDeleteSQL']=["""""","""select * from a"""]

==> InpboxDB-0.1.72b.tar.gz: InpboxDB/InpboxDBTemplates.py <==
#####################
# Templates Service
#
#####################

Templates={}
Sqls={}
Scripts={}

Templates['selectdbForm_html'] =r"""
<dtml-var standard_html_header>
<dtml-var selectdbForm>
<dtml-var standard_html_footer>
"""
Templates['CSS_Def'] =r"""
<style type="text/css">
  <!--
body{
  background-color:white;
  color:black;
}
.usertext {
  text-align:justified;
  font-size: 10pt;

}
.timetext {
  font-size:smaller;
  text-align:right;
}
.menubox{
  border-style:solid;
  border-color:Black;
  padding:0;border-width:1;
}
.menuline{
  color:White;
  background-color:#778899;
  margin:0;
  border-style:solid;
  border-color:#778899;
  border-width:1;
  padding:3;
}
.labeltitle{
  color: Indigo;
  background-color:Azure;
  font-weight: bold;
}
.nonewrap{
  white-space: nowrap;
}
.mestext {
  background-color: White;
  foreground-color: Black;
  border-style: solid;
  border-width: 1;
  border-color: maroon;
  cursor: pointer;
  padding: 2 10 0 10;
}
.javaitem{
  color: black;
  background-color: white;
  border-style:solid;
  border-color:maroon;
  padding:0;
  border-width:1;
}
input.AsciiEditBox {
  ime-mode: disabled;
  border-style: solid;
  border-width: 1;
  border-color: blue;
}
input.KanjiEditBox {
  ime-mode: active;
  border-style: solid;
  border-width: 1;
  border-color: blue;
}
textarea.KanjiEditBox {
  ime-mode: active;
  width: 100%;
  border-style: solid;
  border-width: 1;
  border-color: blue;
  font-size: 12pt;
}
input.PushButton {
  background-color: White;
  foreground-color: Black;
  border-style: solid;
  border-width: 1;
  border-color: saddlebrown;
  cursor: pointer;
  padding: 2 10 0 10;
}
img.left {
  float: left;
  margin-right: 0.8em;
  margin-bottom: 0.5em;
}
img.right {
  float: right;
  margin-right: 0.8em;
  margin-bottom: 0.5em;
}

p {
  clear: both;
  line-height: 1.4;
}

a.tlink{
  text-decoration: none;
  margin-top: 0.5em;
  margin-right: 0.5em;
  margin-left: 0.5em;
  margin-bottom: 0.5em;
  border-style: solid;
  border-width: 1;
  border-color: white;
  background-color:black;
  Color: white;
  font-size: 9pt;
  padding: 0 4 0 4;

}

.tlink a:link {color: #FFFFFF; text-decoration: none;}
.tlink a:visited {color: #FFFF00; text-decoration: none;}
.tlink a:active {color: #FFFFFF; text-decoration: none;}
.tlink a:hover {color:  RED; text-decoration: none;}
.nomal a:link {color: #204050; text-decoration: none;}
.nomal a:visited {color: #204050; text-decoration: none;}
.nomal a:active {color: #466dab; text-decoration: none;}
.nomal a:hover {color:  #991100; text-decoration: none;}
 -->
</style>
"""
Templates['standard_html_footer'] =r"""
</body>
</html>
"""

Templates['standard_html_header'] =r"""
<html>
  <head>
  <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=<dtml-var dbcharset>">
  <dtml-var CSS_Def>
  <title>
   <dtml-var title_or_id>
  </title>
  </head>
<body bgcolor="#FFFFFF" leftmargin="3" topmargin="3" marginwidth="2" marginheight="2">
"""

Templates['index_html'] =r"""
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
<HEAD>
    <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=<dtml-var dbcharset>">
</HEAD>
<dtml-let us="AUTHENTICATED_USER.getUserName()">
<dtml-if "us=='Anonymous User'">
ǰǤȥ桼ǤϡǤޤ
<dtml-else>

  <FRAMESET COLS="20%,*" BORDER=0 FRAMEBORDER=1 FRAMESPACING=1>
    <FRAME SRC="left_html" NAME="menuFrame" SCROLLING=AUTO />
    <FRAME SRC="work_html" NAME="workFrame" SCROLLING=AUTO />
  </FRAMESET>
<NOFRAMES>
̤Ѥˤϥե졼ɽǤ֥饦ɬפǤ.
</NOFRAMES>
</dtml-if>
</dtml-let>
</HTML>
"""
Templates['left_html'] =r"""
<dtml-var standard_html_header>
<form>
<div class="menubox">
<p class="menuline">
˥塼
</p>
<dtml-comment>
<div style="padding-top: 3pt; padding-bottom: 3pt;">&nbsp;<a href="<dtml-var absolute_url>/index_html"><font size="2">˥塼ȥå<font></a></div>
</dtml-comment>
<div style="padding-top: 3pt; padding-bottom: 3pt;">
&nbsp;<a href="&dtml-absolute_url;/selectdbForm_html" TARGET="workFrame">
<font size="2">ǡ١ѹ<font>
</a>
</div>

<div style="padding-top: 3pt; padding-bottom: 3pt;">
&nbsp;<a href="&dtml-absolute_url;/showTable_html" TARGET="workFrame">
<font size="2">ơ֥ɽ<font>
</a>
</div>

</div>
</form>
<dtml-var standard_html_footer>
"""
Templates['work_html'] =r"""
<dtml-var standard_html_header>
<p>ˡ</p>
<p>
ΥץȤϴԤѤǤ<br>
ľ URL áȻפʤ̤ˤʤǤ礦<br>
ƥꤷƤѲ
</p>
<dtml-var standard_html_footer>
"""

Templates['showTable_html'] =r"""
<dtml-var standard_html_header>
<dtml-var showtblistForm>
<dtml-var standard_html_footer>
"""
Scripts['changeMethod']=["""idst, arg, body""","""from Products.PythonScripts.standard import html_quote

request = container.REQUEST
RESPONSE =  request.RESPONSE

context[idst].manage_edit(title='',connection_id='conid',arguments=arg,template=body)

return
"""]

Scripts['updateScript']=["""tbl, startpos""","""from Products.PythonScripts.standard import html_quote

request = container.REQUEST
RESPONSE =  request.RESPONSE

returl='showedittable?tbl=%s&startpos=%s' % (tbl, startpos)
flds = context.getupdateSQL(tbl)
fld = string.split(flds[0],'\\n')
fldlen = len(fld)
sql=""

for i in range(0,fldlen-1):
  typ=context.getdbtype(tbl,fld[i])
  if typ=="s" or typ=="t":
     sql = sql + "%s='''%s'''," % (fld[i], request.form['inptext'][i])
  else:
     sql = sql + '%s=%s,' % (fld[i], request.form['inptext'][i])
if len(sql):
  sql = sql[:-1]
  body = "upsql=context.editUpdateSQL\\n"
  body = body + "upsql(%s)" % sql
  context.upgo.ZPythonScript_edit(params='',body=body)
  context.upgo()


RESPONSE.redirect(returl)
 """]

Scripts['deleteScript']=["""tbl, startpos""","""from Products.PythonScripts.standard import html_quote

request = container.REQUEST
RESPONSE =  request.RESPONSE

returl='showedittable?tbl=%s&startpos=%s' % (tbl, startpos)
flds = context.getdeleteSQL(tbl)
fld = string.split(flds[0],'\\n')
fldlen = len(fld)
sql=""

for i in range(0,fldlen-1):
  typ=context.getdbtype(tbl,fld[i])
  if typ=="s" or typ=="t":
     sql = sql + "%s='''%s'''," % (fld[i], request.form['inptext'][i])
  else:
     sql = sql + '%s=%s,' % (fld[i], request.form['inptext'][i])
if len(sql):
  sql = sql[:-1]
  body = "delsql=context.editDeleteSQL\\n"
  body = body + "delsql(%s)" % sql
  context.delgo.ZPythonScript_edit(params='',body=body)
  context.delgo()


RESPONSE.redirect(returl)
 """]

Scripts['upgo']=["""""",""""""]

Scripts['delgo']=["""""",""""""]

Sqls['editUpdateSQL']=["""""","""select * from a"""]

Sqls['editDeleteSQL']=["""""","""select * from a"""]
